@@ -1268,7 +1268,6 @@ static void _xfdashboard_stage_on_monitor_removed(XfdashboardStage *self,
 	}
 }
 
-#if !CLUTTER_CHECK_VERSION(0, 17, 2)
 /* Screen size has changed */
 static void _xfdashboard_stage_on_screen_size_changed(XfdashboardStage *self,
 														gint inWidth,
@@ -1297,7 +1296,6 @@ static void _xfdashboard_stage_on_screen_size_changed(XfdashboardStage *self,
 		clutter_actor_set_size(CLUTTER_ACTOR(self), inWidth, inHeight);
 	}
 }
-#endif
 
 /* IMPLEMENTATION: ClutterActor */
 
@@ -1722,15 +1720,17 @@ static void xfdashboard_stage_init(XfdashboardStage *self)
 								G_CALLBACK(_xfdashboard_stage_on_application_theme_changed),
 								self);
 
-#if !CLUTTER_CHECK_VERSION(0, 17, 2)
+	/* Resize stage to match screen size and listen for futher screen size changes
+	 * to resize stage again.
+	 * This should only be needed when compiled against Clutter prior to 0.17.2
+	 * because this version or newer ones seem to handle window resizes correctly.
+	 */
+	if(clutter_major_version<1 ||
+		(clutter_major_version==1 && clutter_minor_version<17) ||
+		(clutter_major_version==1 && clutter_minor_version==17 && clutter_micro_version<2))
 	{
 		gint					screenWidth, screenHeight;
 
-		/* Resize stage to match screen size and listen for futher screen size changes
-		 * to resize stage again.
-		 * This should only be needed when compiled against Clutter prior to 0.17.2
-		 * because this version or newer ones seem to handle window resizes correctly.
-		 */
 		screenWidth=xfdashboard_window_tracker_get_screen_width(priv->windowTracker);
 		screenHeight=xfdashboard_window_tracker_get_screen_height(priv->windowTracker);
 		_xfdashboard_stage_on_screen_size_changed(self, screenWidth, screenHeight, priv->windowTracker);
@@ -1739,8 +1739,9 @@ static void xfdashboard_stage_init(XfdashboardStage *self)
 									"screen-size-changed",
 									G_CALLBACK(_xfdashboard_stage_on_screen_size_changed),
 									self);
+
+		g_message("Tracking screen resizes to resize stage");
 	}
-#endif
 }
 
 /* IMPLEMENTATION: Public API */
